import matplotlib.pyplot as plt
from matplotlib import cm
import numpy as np


def plot_clusters(
    X,
    y,
    dim,
    points,
    labels_prefix="cluster",
    points_name="centroids",
    colors=cm.tab10,  # a qualitative map
    # https://matplotlib.org/examples/color/colormaps_reference.html
    #                   colors = ['brown', 'orange', 'olive',
    #                             'green', 'cyan', 'blue',
    #                             'purple', 'pink'],
    #                   points_color = 'red'
    points_color=cm.tab10(10),  # by default the last of the map (to be improved)
):
    """
    Plot a two dimensional projection of an array of labelled points
    X:      array with at least two columns
    y:      vector of labels, length as number of rows in X
    dim:    the two columns to project, inside range of X columns, e.g. (0,1)
    points: additional points to plot as 'stars'
    labels_prefix: prefix to the labels for the legend ['cluster']
    points_name:   legend name for the additional points ['centroids']
    colors: a color map
    points_color: the color for the points
    """
    # plot the labelled (colored) dataset and the points
    labels = np.unique(y)
    for i in range(len(labels)):
        color = colors(i / len(labels))  # choose a color from the map
        plt.scatter(
            X[y == labels[i], dim[0]],
            X[y == labels[i], dim[1]],
            s=10,
            c=[color],  # scatter requires a sequence of colors
            marker="s",
            label=labels_prefix + str(labels[i]),
        )
    plt.scatter(
        points[:, dim[0]],
        points[:, dim[1]],
        s=50,
        marker="*",
        c=[points_color],
        label=points_name,
    )
    plt.legend()
    plt.grid()
    plt.show()
